summary refs log tree commit diff
path: root/gnu/packages/icu4c.scm
diff options
context:
space:
mode:
authorMark H Weaver <mhw@netris.org>2014-02-16 16:38:00 -0500
committerMark H Weaver <mhw@netris.org>2014-02-17 18:47:23 -0500
commit625bd408064605a6ab1107603d8b5bb6353ae9f1 (patch)
tree27469c7da6ebe0816d519ae2d806a153e0e08972 /gnu/packages/icu4c.scm
parent0841dcf7dd8e6c3e474f75cfa5b95a7feaf6f112 (diff)
downloadguix-625bd408064605a6ab1107603d8b5bb6353ae9f1.tar.gz
gnu: icu4c: Upgrade to 52.1.
* gnu/packages/icu4c.scm (icu4c): Upgrade to 52.1.
Diffstat (limited to 'gnu/packages/icu4c.scm')
-rw-r--r--gnu/packages/icu4c.scm6
1 files changed, 3 insertions, 3 deletions
diff --git a/gnu/packages/icu4c.scm b/gnu/packages/icu4c.scm
index 6129662436..aea5d2fae5 100644
--- a/gnu/packages/icu4c.scm
+++ b/gnu/packages/icu4c.scm
@@ -28,7 +28,7 @@
 (define-public icu4c
   (package
    (name "icu4c")
-   (version "50.1.1")
+   (version "52.1")
    (source (origin
             (method url-fetch)
             (uri (string-append "http://download.icu-project.org/files/icu4c/"
@@ -37,7 +37,7 @@
                    (string-map (lambda (x) (if (char=? x #\.) #\_ x)) version)
                    "-src.tgz"))
             (sha256 (base32
-                     "13yz0kk6zsgj94idnlr3vbg8iph5z4ly4b4xrd5wfja7q3ijdx56"))))
+                     "14l0kl17nirc34frcybzg0snknaks23abhdxkmsqg3k9sil5wk9g"))))
    (build-system gnu-build-system)
    (inputs
     `(("patchelf" ,patchelf)
@@ -61,7 +61,7 @@
         (lambda* (#:key #:allow-other-keys #:rest args)
          (let ((configure (assoc-ref %standard-phases 'configure)))
            ;; patch out two occurrences of /bin/sh from configure script
            ;; that might have disappeared in a release later than 50.1.1
            (substitute* "configure"
              (("`/bin/sh")
              (string-append "`" (which "bash"))))
@@ -61,7 +61,7 @@
          (let ((configure (assoc-ref %standard-phases 'configure)))
            ;; patch out two occurrences of /bin/sh from configure script
-           ;; that might have disappeared in a release later than 50.1.1
+           ;; that might have disappeared in a release later than 52.1
            (substitute* "configure"
              (("`/bin/sh")